import os
import sys
dir_path = os.path.dirname(os.path.realpath(__file__))
sys.path.append(os.path.abspath(os.path.join(dir_path, "./lib")))

# import importlib
# py_major_version = sys.version_info[0]
# py_minor_version = sys.version_info[1]
# globals()["nmotion_transport"] = importlib.import_module(f'libnmotion_transport_python_{py_major_version}{py_minor_version}')
# globals()["nmotion_transport"] = importlib.import_module(f'libnmotion_transport_python')

import libnmotion_transport_python as nmotion_transport
from .UsbInterface import USBInterface
from typing import Any

class IMU():
    __imu: Any = None
    id: int = None
    
    def __init__(self, id: int, interface: USBInterface):
        self.id = id
        interface = interface
        self.__imu = nmotion_transport.IMU(id, interface.getInterface())
    
    def getRotationVectorData(self) -> 'tuple[float, float, float, float]':
        return self.__imu.getRotationVectorData()

    def getRawAccelerometerData(self) -> 'tuple[int16_t, int16_t, int16_t]':
        return self.__imu.getRawAccelerometerData()
    
    def getRawGyroData(self) -> 'tuple[int16_t, int16_t, int16_t]':
        return self.__imu.getRawGyroData()
    
    def getRawMagnetometerData(self) -> 'tuple[int16_t, int16_t, int16_t]':
        return self.__imu.getRawMagnetometerData()

    def getLinearAccelerometerData(self) -> 'tuple[float, float, float, uint8_t]':
        return self.__imu.getLinearAccelerometerData()

    def getAccelerometerData(self) -> 'tuple[float, float, float, uint8_t]':
        return self.__imu.getAccelerometerData()
    
    def getGyroData(self) -> 'tuple[float, float, float, uint8_t]':
        return self.__imu.getGyroData()

    def getMagnetometerData(self) -> 'tuple[float, float, float, uint8_t]':
        return self.__imu.getMagnetometerData()

    def getUncalibratedGyroData(self) -> 'tuple[float, float, float]':
        return self.__imu.getUncalibratedGyroData()

    def getUncalibratedGyroBiasData(self) -> 'tuple[float, float, float]':
        return self.__imu.getUncalibratedGyroBiasData()

    def getEulerAngles(self) -> 'tuple[float, float, float]':
        return self.__imu.getEulerAngles()

    def getGravityData(self) -> 'tuple[float, float, float]':
        return self.__imu.getGravityData()

    def enableRotationVector(self, time_interval: int) -> int:
        return self.__imu.enableRotationVector(time_interval)
    
    def disableRotationVector(self) -> int:
        return self.__imu.disableRotationVector()
    
    def enableRawAccelerometer(self, time_interval: int) -> int:
        return self.__imu.enableRawAccelerometer(time_interval)
    
    def disableRawAccelerometer(self) -> int:
        return self.__imu.disableRawAccelerometer()

    def enableRawGyro(self, time_interval: int) -> int:
        return self.__imu.enableRawGyro(time_interval)
    
    def disableRawGyro(self) -> int:
        return self.__imu.disableRawGyro()

    def enableRawMagnetometer(self, time_interval: int) -> int:
        return self.__imu.enableRawMagnetometer(time_interval)
    
    def disableRawMagnetometer(self) -> int:
        return self.__imu.disableRawMagnetometer()

    def enableLinearAccelerometer(self, time_interval: int) -> int:
        return self.__imu.enableLinearAccelerometer(time_interval)
    
    def disableLinearAccelerometer(self) -> int:
        return self.__imu.disableLinearAccelerometer()

    def enableAccelerometer(self, time_interval: int) -> int:
        return self.__imu.enableAccelerometer(time_interval)
    
    def disableAccelerometer(self) -> int:
        return self.__imu.disableAccelerometer()

    def enableGyro(self, time_interval: int) -> int:
        return self.__imu.enableGyro(time_interval)
    
    def disableGyro(self) -> int:
        return self.__imu.disableGyro()

    def enableMagnetometer(self, time_interval: int) -> int:
        return self.__imu.enableMagnetometer(time_interval)
    
    def disableMagnetometer(self) -> int:
        return self.__imu.disableMagnetometer()

    def enableUncalibratedGyro(self, time_interval: int) -> int:
        return self.__imu.enableUncalibratedGyro(time_interval)
    
    def disableUncalibratedGyro(self) -> int:
        return self.__imu.disableUncalibratedGyro()
    
    def enableGravity(self, time_interval: int) -> int:
        return self.__imu.enableGravity(time_interval)
    
    def disableGravity(self) -> int:
        return self.__imu.disableGravity()